<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Chiudi (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Riduci</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Espandi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Chiudi avviso</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln parole</numerusform>
            <numerusform>%Ln parole</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuti</numerusform>
            <numerusform>%Ln minuti</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% minuti su %Ln</numerusform>
            <numerusform>%L1% minuti su %Ln</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% su %Ln parole</numerusform>
            <numerusform>%L1% parole su %Ln</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progresso giornaliero</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Sequenza più lunga</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Sequenza corrente</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>n/d</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n giorni</numerusform>
            <numerusform>%n giorni</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% dell&apos;obiettivo giornaliero</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Imposta lingua</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Senza titolo %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (sola lettura)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Impossibile salvare &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Salva con nome</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Impossibile sovrascrivere &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Rinomina file</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Impossibile rinominare &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Ricaricare il file?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Ricaricare il file &apos;%1&apos; dal disco?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Tutte le modifiche non salvate andranno perse.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Se si salva nel formato solo testo, la formattazione andrà persa. Eliminare la formattazione?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>File modificato</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Il file &apos;%1&apos; è stato modificato da un altro programma.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Vuoi ricaricare il file?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>File eliminato</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Il file &apos;%1&apos; è stato modificato da un altro programma.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Vuoi salvare il file o chiuderlo?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire l&apos;archivio.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Sostituisci con:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignora maiuscole/minuscole</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Solo parole intere</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Espressioni regolari</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cerca su</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cerca giù</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Sostituisci</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Sostitusci &amp;tutto</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Sostituire %n istanze?</numerusform>
            <numerusform>Sostituire %n istanze?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frase non trovata.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Documenti di testo</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Tutti i formati supportati</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Controllo ortografico...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nessun suggerimento trovato)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Apri immagine</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona una lingua da utilizzare per l&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingua di sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Per modificare la lingua è necessario riavviare l&apos;applicazione.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire l&apos;archivio.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiche</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Controllo ortografico</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Seleziona  un dizionario</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire l&apos;archivio.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>L&apos;archivio non contiene un dizionario utilizzabile.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tasti di scelta rapida</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>C&apos;è un conflitto tra i tasti di scelta rapida. Continuare comunque?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Il dizionario &quot;%1&quot; esiste già. Vuoi sostituirlo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Obiettivo giornaliero</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuti:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Parole:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centra sempre in verticale</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blocca cursore di inserimento</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Font &quot;morbide&quot;</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Suoni della macchina da scrivere</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Virgolette:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doppie</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Singole</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scene</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divisore</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Salvataggio</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Ricorda la posizione del cursore</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Conteggio parole</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Conteggio pagine</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Conteggio paragrafi</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Conteggio caratteri</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caratteri:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragrafi:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo di conteggio parole</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Resettare a zero i progressi di oggi?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Scrivi il BOM (Byte Order Mark) nei file di puro testo</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Formato predefinito:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Azzera le statistiche di oggi</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Salva cronologia</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostra sequenze</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progresso minimo per sequenza:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Rileva spazi tra le parole</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividi per sei il conteggio dei caratteri</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Conta ciascuna lettera come una parola</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmo di conteggio pagine</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stile</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Solo testo</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Testo affiancato alle icone</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Testo sotto le icone</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posizione testo:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Azioni</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Sposta su</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Sposta giù</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Aggiungi separatore</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Tasto di scelta rapida</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Controllo ortografico durante la digitazione</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignora parole MAIUSCOLE</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignora parole con numeri</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dizionario personale</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Rimuovere il dizionario attualmente in uso?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interfaccia utente</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Mostra sempre la barra di scorrimento</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Mostra sempre la barra superiore</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Mostra sempre la barra inferiore</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Questo file non è un file RTF supportato.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Fine del file raggiunta inaspettatamente.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Giù</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Sposta scene su</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Su</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Attiva lista scene</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Visualizza lista scene (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Nascondi lista scene (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Sposta scene giù</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Ridimensiona lista scene</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Predefinita</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestione sessioni</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>Sess&amp;ioni</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Passa a</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nuova sessione</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Sessione duplicata</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Rinomina sessione</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Eliminare la sessione selezionata?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nome della sessione:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Il nome della sessione richiesto è già in uso.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nuova...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maiusc+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Gestisci...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Maiusc+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Ripristina predefinito</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Tasto di scelta rapida:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Sostituzione virgolette...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Attendere prego</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Controllo ortografico</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungi</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignora</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Ignora &amp;tutto</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Sostituisci</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Sostituisci t&amp;utto</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>La parola evidenziata in rosso non è presente nel dizionario:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Sostituisci con:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Controllo ortografico...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Attendere prego</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Continuare il controllo dall&apos;inizio del file?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Controllo ortografico completato.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Simboli usati recentemente</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Tutti i simboli</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocchi</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Nessuna immagine</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Piastrellato</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrato</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Allargato</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Scalato</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoomato</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Angoli arrotondati sfondo del testo</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Raggio:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Sfondo del testo sfumato</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Ombra sfondo del testo</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Orientamento verticale:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margini</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Finestra:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Pagina:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Applica rientro ad ogni a capo</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Sopra:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Sotto:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Modifica tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Sfondo della finestra</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Sfondo del testo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tipo di carattere:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Errori di ortografia:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Interlinea</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Singola</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 righe</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doppia</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporzionale</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Spaziatura paragrafi</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Rientro prima riga:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nuovo tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Dolce blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Vecchia scuola</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Sogni dallo spazio</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Scrittoio</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizza</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Cancellare il tema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temi (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importa tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Esporta tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Cieli amari</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Incantesimo</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Giochiamo alla spia</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquillità</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Cancellare il conteggio del tempo?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Parole:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pagine:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragrafi:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caratteri:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Imposta ritardo</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Imposta tempo</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Ritardo:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Promemoria:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nessun timer in esecuzione</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Documenti recenti</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Annullare le modifiche al timer?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Caricamento del tema</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Caricamento dei suoni</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Info su FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un semplice elaboratore di testi a schermo intero</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utilizza icone del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Sotto licenza &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caratteri: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pagine: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragrafi: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Parole: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Apertura di %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Senza nome %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Mostra tutti i documenti</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Passa al documento successivo</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Passa al documento precedente</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Passa al primo documento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Passa all&apos;ultimo documento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Passa al documento %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Caricamento delle impostazioni</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>La cache di ripristino non è scrivibile.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter non è stato chiuso correttamente.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Ripristinare i file dalla cache?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Non è stato possibile aprire alcuni file.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Alcuni file sono stati aperti in sola lettura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; è più recente della copia memorizzata nella cache.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Sovrascrivere il file più recente?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Salvare le modifiche?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Salvare le modifiche al file &apos;%1&apos; prima di chiudere?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Le modifiche apportate al file andranno perse se non vengono prima salvate.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Impossibile caricare i suoni della macchina da scrivere.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>&amp;Ricarica</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Sal&amp;va con nome...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Rino&amp;mina...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Salva &amp;tutto</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestione sessioni</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nuova sessione</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Stam&amp;pa...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Ta&amp;glia</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Incolla senza &amp;formattazione</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleziona &amp;tutto</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Seleziona &amp;scena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmato</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Grassetto</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Corsivo</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Sottolineato</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>B&amp;arrato</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Ap&amp;ice</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Pedice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>A&amp;llinea testo a sinistra</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>C&amp;entra testo</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Allinea testo a &amp;destra</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Giustifica &amp;testo</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Riduci rientro</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>A&amp;umenta rientro</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>&amp;Blocca testo a sinistra</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Bl&amp;occa testo a destra</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Trova succ&amp;essivo</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Trova pre&amp;cedente</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Sostituisci...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Virgolette</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Aggiorna &amp;documento</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Aggiorna &amp;selezione</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Controllo &amp;ortografico...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Imposta &amp;lingua</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Timer...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;imboli</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Progresso giornaliero</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostra &amp;barra degli strumenti</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Mostra &amp;icone nei menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Testo a &amp;fuoco</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>&amp;Minimizza</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temi...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferenze...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Disattiva messa a fuoco</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Metti a fuoco una linea</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Metti a fuoco tre linee</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragrafo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Metti a fuoco il paragrafo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Lingua &amp;applicazione...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Alcuni file non sono supportati e pertanto non è possibile aprirli.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Non attivo</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Una linea</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tre linee</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni su FocusWriter</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Imp&amp;osta pagina</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Intestazione</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Intestazione &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Intestazione &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Intestazione &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Intestazione &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Intestazione &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Intestazione &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normale</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Aggiorna virgolette nel documento</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Aggiorna virgolette nel testo selezionato</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>File da aprire nella sessione corrente.</translation>
    </message>
</context>
</TS>
